@@ -8,7 +8,7 @@ def main():
   print 'Exporting Caltech101 dataset to redistributable HDF5 file "' + dbfile + '"'
 
   print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile, datastep=100, asyncread=False, verbose=True)
+  db = Viset(dbfile, datastep=100, async=False, verbose=True)
   for (im,annotation) in db[0]:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     imshow(im, title=annotation['category'])
