@@ -7,7 +7,7 @@ def main():
   db = Viset(dbfile, datastep=1, async=False, verbose=True)
   for (im,annotation) in db[0]:
     imshow(im, title='horses')
-    print annotation['mask']  # FIXME: mask image should be a viset type
+    imshow(annotation['mask'], title='mask')
     
 if __name__ == '__main__':
   main()
