@@ -29,8 +29,8 @@ class LabelMe(DetectionViset, UrlViset):
         return filelist
   
     def export(self, redo=False):    
-        # Create new database
-        (self.dbobj, dbname, dbfile, dburl, cachedir) = self.create(self.dbname, self.dbtype, self.dbimtype, self.dbversion)
+        # Create empty database
+        self.create()
 
         # Fetch data necessary to initial construction
         print('[viset.labelme]: scraping imagery from ' + self.IMURL)
@@ -41,7 +41,7 @@ class LabelMe(DetectionViset, UrlViset):
         # Create me (image list only for now)
         id = 0
         for im in imlist:
-            self.add_detection(0, '', id, 0,0,0,0)
+            self.dbview.add_detection(0, '', id, 0,0,0,0)
             id += 1
         self.write()
         id = 0
@@ -52,13 +52,13 @@ class LabelMe(DetectionViset, UrlViset):
 
         # Cleanup
         self.close()
-        return dbfile
+        return self.dbfile
 
 class LabelMe3(LabelMe):
     IMURL = 'http://people.csail.mit.edu/brussell/research/LabelMe/Images/'
     ANNOURL = 'http://people.csail.mit.edu/brussell/research/LabelMe/Annotations/'
     SHA1 = None
-    dbname = 'labelme3'
+    _dbname = 'labelme3'
 
 
 
