@@ -89,12 +89,12 @@ def keyboard():
 
 
 def touch(filename, mystr=''):
-    f = open(filename, 'a')
+    f = open(filename, 'w')
     f.write(str(mystr))
     f.close()
 
 def setfetched(cachedir):
-    touch(path.join(cachedir, '.fetched'), mystr=str(datetime.datetime.now()))
+    touch(path.join(cachedir, '.fetched'), mystr=str(str(datetime.datetime.now())+'\n'))
 
 def wasfetched(cachedir):
     return isfile(path.join(str(cachedir), '.fetched'))
