@@ -215,20 +215,29 @@ class SegmentationView(VisetView):
         tbl.flush()
         return tbl
         
-    def add_segmentation(self, url_mask, id_img):
+    def add_segmentation(self, url_mask, id_img, category=None):
         if self._dbrow is None:
             self._dbrow = self.db.dbobj.root.annotation.segmentation.row
         self._dbrow['mask'] = url_mask
         self._dbrow['id_img'] = id_img        
+        self._dbrow['category'] = category  
         self._dbrow.append()
     
     def read(self, id_anno):
         id_img = self.dbtbl[id_anno]['id_img']
-        impath = self.db.dbobj.root.images[id_img]['url']
+        impath = self.db.dbobj.root.images[id_img]['url']	
         im = viset.types.Image(impath, cachedir=self.db.cachedir, verbose=self.db.verbose, imcodec=self.db.imcodec())
+        maskpath = self.dbtbl[id_anno]['mask']
+        if maskpath == '':
+			mask = None
+        else:
+			mask = viset.types.Image(maskpath, cachedir=self.db.cachedir, verbose=self.db.verbose, imcodec=self.db.imcodec())
         anno = self.dbtbl[id_anno]
         if self.async:
+            anno = {'id_category':anno['id_category'], 'category':anno['category'], 'mask':mask}            
             return (im,anno)  # numpy structured array tuple
         else:
+            if mask is not None:
+                mask = mask.get()
+            anno = {'id_category':anno['id_category'], 'category':anno['category'], 'mask':mask}                        
             return (im.get(),anno)  # numpy structured array tuple
-
